summaryrefslogtreecommitdiff
path: root/src/rmd_opendev.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/rmd_opendev.h')
-rw-r--r--src/rmd_opendev.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/rmd_opendev.h b/src/rmd_opendev.h
index 06dfc64..64ec8a5 100644
--- a/src/rmd_opendev.h
+++ b/src/rmd_opendev.h
@@ -46,7 +46,7 @@
*
* \param periodsize Size of a period(can be NULL)
*
* \param periodtime Duration of a period(can be NULL)
*
* \param hardpause Set to 1 when the device has to be stopped during pause
* and to 0 when it supports pausing
@@ -59,7 +59,7 @@ snd_pcm_t *rmdOpenDev(const char *pcm_dev,
unsigned int *frequency,
snd_pcm_uframes_t *buffsize,
snd_pcm_uframes_t *periodsize,
- unsigned int *periodtime,
+ unsigned int *periodtime_us,
int *hardpause);
#else
/**
@@ -46,7 +46,7 @@
* \param periodsize Size of a period(can be NULL)
*
-* \param periodtime Duration of a period(can be NULL)
+* \param periodtime_us Duration of a period(can be NULL)
*
* \param hardpause Set to 1 when the device has to be stopped during pause
© All Rights Reserved